@@ -320,21 +320,19 @@
 #define __NR_memfd_create			319
 #define __NR_kexec_file_load			320
 #define __NR_bpf				321
-
-
-#undef __NR_fstatat
-#undef __NR_pread
-#undef __NR_pwrite
-#undef __NR_getdents
-#define __NR_fstatat __NR_newfstatat
-#define __NR_pread __NR_pread64
-#define __NR_pwrite __NR_pwrite64
-#define __NR_getdents __NR_getdents64
-#define __NR_fadvise __NR_fadvise64
-
-
-
-/* Repeat with SYS_ prefix */
+#define __NR_execveat				322
+#define __NR_userfaultfd			323
+#define __NR_membarrier				324
+#define __NR_mlock2				325
+#define __NR_copy_file_range			326
+#define __NR_preadv2				327
+#define __NR_pwritev2				328
+#define __NR_pkey_mprotect			329
+#define __NR_pkey_alloc				330
+#define __NR_pkey_free				331
+#define __NR_statx				332
+#define __NR_io_pgetevents			333
+#define __NR_rseq				334
 
 #define SYS_read				0
 #define SYS_write				1
@@ -657,16 +655,17 @@
 #define SYS_getrandom				318
 #define SYS_memfd_create			319
 #define SYS_kexec_file_load			320
-#define SYS_bpf					321
-
-#undef SYS_fstatat
-#undef SYS_pread
-#undef SYS_pwrite
-#undef SYS_getdents
-#define SYS_fstatat SYS_newfstatat
-#define SYS_pread SYS_pread64
-#define SYS_pwrite SYS_pwrite64
-#define SYS_getdents SYS_getdents64
-#define SYS_fadvise SYS_fadvise64
-
-
+#define SYS_bpf				321
+#define SYS_execveat				322
+#define SYS_userfaultfd			323
+#define SYS_membarrier				324
+#define SYS_mlock2				325
+#define SYS_copy_file_range			326
+#define SYS_preadv2				327
+#define SYS_pwritev2				328
+#define SYS_pkey_mprotect			329
+#define SYS_pkey_alloc				330
+#define SYS_pkey_free				331
+#define SYS_statx				332
+#define SYS_io_pgetevents			333
+#define SYS_rseq				334
